@@ -73,6 +73,8 @@ async def _(bot: Bot, event: Event, state: T_State):
         setting = load_setting(group_id)
         message += "插件列表如下："
         for plugin in plugin_list:
+            if not plugin in setting.keys():
+                setting[plugin]=True
             message += f'\n[{"o" if setting[plugin] else "x"}] {plugin}'
         await plugin_manager.finish(message)
 
